%global debug_package %{nil}

Summary: Setup RT/low-latency environment details
Name: realtime-setup
Version: 2.2.3
Release: 4%{?dist}
License: GPLv2
URL:  https://gitlab.com/rt-linux-tools/realtime-setup.git
Source0: https://gitlab.com/rt-linux-tools/${name}/-/archive/v%{version}/%{name}-v%{version}.tar.bz2

BuildRequires: gcc make
BuildRequires: systemd systemd-rpm-macros

Requires: pam systemd
Requires: kexec-tools
Requires: tuna tuned
Requires: tuned-profiles-realtime


%description
Configure details useful for low-latency environments.

Installation of this package results in:
  - creation of a realtime group
  - adds realtime limits configuration for PAM
  - adds udev specific rules for threaded irqs and /dev/rtc access
  - adds /usr/bin/slub_cpu_partial_off to turn off cpu_partials in SLUB
  - adds net-socket timestamp static key daemon (realtime-entsk)

The slub_cpu_partial_off script is used to turn off the SLUB slab allocator's
use of cpu-partials, which has been known to create latency-spikes.

The realtime-entsk program is a workaround for latency spikes caused when the
network stack enables hardware timestamping and activates a static key. The
realtime-entsk progam is activated by the systemd service included and merely
enables the timestamp static key and pauses, effectively activating the static
key and never exiting, so no deactivation/activation sequences will be seen.

Neither the slub script or realtime-entsk are active by default.


%prep
%autosetup -n %{name}-v%{version}

%build
%make_build CFLAGS="%{build_cflags} -D_GNU_SOURCE" all

%install
%make_install DEST=%{buildroot}

%post
/usr/sbin/groupadd -f -g 71 realtime

%preun
%systemd_preun realtime-setup.service

%files
%license gpl-2.0.txt
%config(noreplace) %{_sysconfdir}/security/limits.d/realtime.conf
%config(noreplace) %{_sysconfdir}/udev/rules.d/99-rhel-rt.rules
%config(noreplace) %{_sysconfdir}/sysconfig/realtime-setup
%{_bindir}/slub_cpu_partial_off
%{_bindir}/realtime-setup
%{_sbindir}/realtime-entsk
%{_sbindir}/kernel-is-rt
%{_unitdir}/realtime-setup.service
%{_unitdir}/realtime-entsk.service


%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.2.3-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.2.3-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.2.3-2
- Rebuilt for OpenCloudOS Stream 23

* Tue Mar 21 2023 Yi Lin <nilusyi@tencent.com> - 2.2.3-1
- package init.
